@@ -6,5 +6,8 @@ namespace pan
   bool _debug_flag = false;
   bool _debug_verbose_flag = false;
   bool _verbose_flag = false;
-  std::ofstream dbg_file;
+  std::ofstream _dbg_file;
+
+  bool _dbg_ssl = false;
+
 }
