@@ -13,8 +13,8 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 #ifndef _PrefsFile_h_
@@ -29,12 +29,12 @@ namespace pan
     public:
       PrefsFile (const StringView& filename);
       ~PrefsFile ();
+      virtual void save () const;
 
     private:
       std::string _filename;
 
     private:
-      void save () const;
       void set_from_file (const StringView& filename);
       void set_from_xml (const StringView& xml_string);
   };
